#
# spec file for package jira-cli
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#
# nodebuginfo


%define __arch_install_post export NO_BRP_STRIP_DEBUG=true
%define shortname jira
Name:           jira-cli
Version:        1.6.0
Release:        1.1
Summary:        CLI tool for Atlassian JIRA inspired by the Github CLI tool
License:        MIT
Group:          Development/Tools/Other
URL:            https://github.com/ankitpokhrel/jira-cli
Source:         %{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  golang(API) >= 1.19
# For completions packages
BuildRequires:  fish
BuildRequires:  zsh
# For SLE_15_SP4
BuildRequires:  zstd

%description
JiraCLI is an interactive command line tool for Atlassian Jira that will help
you avoid Jira UI to some extent. This tool is not yet considered complete but
has all the essential features required to improve your workflow with Jira. The
tool started with the idea of making issue search and navigation as
straightforward as possible. The tool now includes all necessary features like
issue creation, cloning, linking, ticket transition, and much more. The TUI is
heavily inspired by the GitHub CLI.

%package bash-completion
Summary:        Bash Completion for %{name}
Requires:       %{name}
Requires:       bash-completion
Supplements:    (%{name} and bash-completion)
BuildArch:      noarch

%description bash-completion
Bash command line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Requires:       %{name}
Requires:       fish
Supplements:    (%{name} and fish)
BuildArch:      noarch

%description fish-completion
Fish command line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Requires:       %{name}
Requires:       zsh
Supplements:    (%{name} and zsh)
BuildArch:      noarch

%description zsh-completion
Zsh command line completion support for %{name}.

%prep
%autosetup -a 1

%build
# Build the binary.
go build \
   -mod=vendor \
   -tags extended \
   -buildmode=pie \
   ./cmd/%{shortname}

# generated via CLI--there are a number of manpages all suffixed as .7
./%{shortname} man --generate --output .
gzip %{shortname}*.7

for sh in bash zsh fish
do
   ./%{shortname} completion $sh > %{shortname}.${sh}
done

%install
# Install the binary.
install -D -m 0755 %{shortname} "%{buildroot}/%{_bindir}/%{shortname}"
install -D -m 0644 -t "%{buildroot}/%{_mandir}/man7/" %{shortname}*.7.gz
install -Dm644 %{shortname}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{shortname}
install -Dm644 %{shortname}.zsh  %{buildroot}%{_datadir}/zsh/site-functions/_%{shortname}
install -Dm644 %{shortname}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{shortname}.fish

%files
%doc README.md
%license LICENSE
%{_bindir}/%{shortname}
%{_mandir}/man7/%{shortname}*.7.gz

%files bash-completion
%{_datadir}/bash-completion/completions/%{shortname}

%files fish-completion
%{_datadir}/fish/vendor_completions.d/%{shortname}.fish

%files zsh-completion
%dir %{_datadir}/zsh/site-functions
%{_datadir}/zsh/site-functions/_%{shortname}

%changelog
* Fri Apr 25 2025 Holden Fried <holden@opensuse.org>
- Update to version 1.6.0:
  * ci: Upgrade goreleaser
  * fix: Tag stripping in plain mode (#839)
  * chore(deps): bump golang.org/x/net from 0.37.0 to 0.38.0 (#838)
  * Update README.md
  * chore(deps): Upgrade spinner, glamour, go-keyring and related deps (#833)
  * feat: Add easy issue search to list cmd (#769)
  * fix: Add shell completion to brew install; closes #651 (#795)
  * feat: Allow adding internal comment on JSD (#825)
  * feat: Accept multiple replace strings on clone (#811)
  * dev: Upgrade docker config
  * feat: Add option to output issue creation result as Json (#775)
  * fix: use `tview.Escape` with standard square brackets (#828)
  * chore(deps): Upgrade to go1.24
  * chore(deps): bump golang.org/x/net from 0.33.0 to 0.36.0 (#831)
  * feat: Respect API token for `mtls` auth (#783)
  * fix: case insensitive sub-task comparison (#793)
  * Update README
  * ci: Upgrade linter (#808)
  * Update golang.org/x/net package to version 0.33.0 (#806)
- Packaging improvements:
  * Convert to using obs_scm with version in _service
  * Generate separate completions packages
  * Generate and include upstream-provided manpages
* Fri Apr 25 2025 Holden Fried <holden@opensuse.org>
- Update to version 1.5.2:
  * chore: Add tests for sprint close (#778)
  * [feat] Add cli method for close sprint with supporting jira client methods (#756)
  * fix: regression introduced by new OriginalEstimate attribute (#767)
  * feat: Allow updating parent on edit (#765)
  * feat: Add original estimate option to issue creation (#748)
  * Improve zsh autocomplete directions (#739)
  * dep: Upgrade tcell & tview (#734)
  * dep: Upgrade cobra and viper (#732)
  * dep: Upgrade browser, testify, go-keyring (#731)
  * dep: Upgrade glamour (#730)
  * ci: Upgrade linter (#729)
  * chore: Minor cleanup
  * fix: Epic description overridden in no-input mode (#728)
  * feat(718): issue view: --raw option (#720)
  * win: Respect `WT_SESSION` variable. (#706)
  * ci: Update GitHub Actions steps (#707)
* Mon Jun  3 2024 georg.pfuetzenreuter@suse.com
- Update to version 1.5.1:
  * fix: Skip auth type prompt if already set (#701)
  * fix: Properly close created files (#702)
  * build: Upgrade goreleaser
  * feat: Add support for updating the estimate (#669)
  * fix: Respect jira timezone (#697)
  * fix: Bring bearer back (#696)
  * fix: Jira init broken due to authtype value (#694)
  * ci: Upgrade workflow + linter (#695)
  * chore(Dockerfile): bump go & alpine versions (#691)
  * chore(deps): bump golang.org/x/net from 0.12.0 to 0.17.0 (#671)
  * chore: Add supporters
  * [feat] Add `mtls` authentication for client certificate auth (#615)
  * feat: affects version (#642)
  * fix: Issue with no-input on create (#655)
  * deps: Upgrade all (#643)
  * feat: Enable issue edit to read body from stdin (#619)
  * chore: go mod tidy
  * fix: Comment author name is not always displayed (#618)
  * feat: Allow different jira server for API and for UI (#613)
  * fix: Issue with epic field on create (#607)
  * dep: Upgrade cobra to v1.7.0 (#608)
  * fix: Issue with value assignment in init (#606)
  * ci: Upgrade actions and linter (#590)
  * ci: Upgrade go version
  * ci: Make linter happy
  * fix: Detect if Jira v8 server is not using the /createmeta REST endpoint (#574)
  * fix: Issue with -c flag on config generation (#582)
  * feat: Support for adding watcher to Issue (#584)
  * chore: Some minor README changes
  * chore(deps): bump golang.org/x/net from 0.4.0 to 0.7.0 (#575)
  * ehc: Improve PAGER selection (#570)
  * feat: Filter by multiple statuses (#573)
  * fix: Use http client wrapper instead of round trip (#530)
  * feat: Add help page (#563)
  * fix: Worklog comment don't work together with prompt (#562)
  * feat(tui): Allow issue transition from the ui (#544)
  * fix: Shell completion for Fish and PowerShell (#553)
  * chore: Refactor jira client (#543)
  * chore(tui): Refactor table data access (#542)
  * tui: Use tview Modal instead of the extended one (#541)
  * feat: Use single char ellipsis instead of triple dot (#540)
  * feat: Allow to set reporter on issue create (#539)
  * chore: Update bug report template
  * doc: Fix example scripts
  * chore: Remove duplication in epic and issue create (#537)
  * ehc: Auto fallback to plain output on notty (#538)
  * ci: Upgrade golangci-lint to v1.50.1 (#536)
  * ehc: Make assignee operation atomic on create (#531)
  * fix(build): Invalid commit hash in docker image (#535)
  * dep: Upgrade golang to v1.19 (#534)
  * doc: Update README
  * dep: Upgrade all (#532)
  * feat: Add warning for invalid custom field (#528)
  * ehc: Remove viper dependency from pkg (#526)
  * doc: Fix typo
  * doc: Shorten installation section
  * ci: Fix build branch
  * fix: Respect editor env vars in Windows (#524)
  * doc: Upgrade badge URL
  * chore: Minor cleanup
  * fix: Improve support for pager (#503)
  * fix: Make board selection optional (#502)
  * feat: allow setting of fixed columns in the list of issues (#509)
  * feat: Add labels to the issue listing (#506)
  * feat: Filter issues by the absence of label(s) (#505)
  * ci: Multi-arch docker image (#508)
  * fix: Discrepancy in --insecure flag (#507)
  * doc: Add scoop installation process (#497)
  * feat: Resolution, assignee & comment on issue move (#492)
  * doc: Update zsh completion command
  * doc: Update help for completion cmd (#491)
  * feat: Add weblink to issue (#483)
  * feat: Add support for project datatype in custom fields (#482)
  * fix: Option to show issues from all projects in sprint (#475)
  * feat: Make date time input in worklog add flexible (#465)
  * doc: Minor updates
  * doc: Add Nix package (#458)
  * doc: Add pkg maintainers
  * doc: Add link to project in help (#456)
  * chore: Minor refactoring
  * feat: Allow to set start datetime on worklog add (#453)
  * feat: Support for Jira v9 (#447)
  * feat: Add serverinfo command (#440)
  * doc: Fix typo
* Sun Aug 14 2022 chrisbcoutinho@gmail.com
- Update to version 1.1.0:
  * fix: Flickering issue (#436)
  * chore(doc): Add resources section
  * Add open collective
  * Add FUNDING.yml
  * dev: Upgrade jira to 8.22.1
  * chore(doc): Add missing articles (#423)
  * ehc: Increase max col width + some cleanup (#427)
  * fix(minor): Use pointer receiver to avoid heavy copying (#426)
  * chore: Remove deprecated ioutil usage (#422)
  * chore: s/\"%%s\"/%%q/g (#421)
  * feat: Make selection highlight customizable (#419)
  * fix: Issue with insecure TLS config (#413)
  * fix: Remove dead code in comment add (#411)
  * feat: Ability to add worklog (#410)
  * fix: Issue with default assignee and unassign from tui (#405)
  * doc: Add instructions for docker
* Wed Jul  6 2022 jkowalczyk@suse.com
- Initial package version 1.0.0:
  * fix: Use md ext to trigger syntax highlighting (#400)
  * dep: Upgrade cobra to 1.5 and viper to 1.12 (#399)
  * dep: Upgrade AlecAivazis/survey + sync editor ext (#398)
  * dep: Upgrade tview, tcell and testify (#397)
  * ci: Fix/refactor workflow (#396)
  * feat: Allow project filter in raw jql (#395)
  * fix: Editing issue with custom field in non interactive mode (#391)
  * ci: Upgrade golangci linter version (#394)
  * ci: Add workflow to publish docker image to ghcr (#392)
  * Add a Dockerfile (#387)
  * fix: Subtask clone (#383)
  * feat: Show subtasks in issue view (#382)
  * feat: Jira init non-interactive (#381)
  * fix: Issue with query param in user assignment (#380)
  * doc: Change some wordings
  * doc: Update contribution notice
  * feat: Support custom fields on issue edit (#377)
  * chore: Bump copyright year
  * doc: Minor updates
  * feat: Allow removing fixVersions on edit (#376)
  * feat: Allow removing component on edit (#374)
  * dep: Upgrade cobra to 1.4.0 (#373)
  * fix: Support creating issues with custom subtask type (#372)
  * feat: Allow removing labels on edit (#371)
  * fix!: Append components on edit instead of overriding (#368)
  * feat: Allow to edit release-info/fixVersions (#365)
  * feat: Allow to set custom fields on epic create (#364)
  * chore: Minor refactoring and doc update
  * fix: Add additional check for total boards returned (#360)
  * feat: Add issues unlink command (#347)
  * fix!: Replace limit flag with paginate (#359)
  * doc: Update some details related to API tokens
  * feat: Add support for OS keyrings/-chains (#348)
  * fix: Assign parent key as is on edit (#351)
  * fix: OOM bug on issue view (#350)
  * fix: Issue with assigning user (#321)
  * doc: Add details for custom flag
  * feat: Support custom fields on issue create (#319)
  * ci: Upgrade linter
  * feat: Ability to delete issue (#336)
  * chore: Improve docs
  * chore: Minor refactoring and fixes (#335)
  * feat: Initial support for netrc (#329)
  * feat: Support refresh for issues list (#325)
  * fix: Panic on empty sub-list (#330)
  * chore: Minor refactoring and fixes (#328)
  * feat: Support auth with personal access tokens (#327)
  * doc: Clarify help for sprint issues column flag (#320)
  * fix: Jira wiki parser (#326)
  * feat: Add search option for boards on jira init (#322)
  * feat: Use md ext for tmp file to trigger syntax highlighting (#318)
  * feat!: Append labels instead of overwritting on edit (#300)
  * fix: Get subtask handle from config (#296)
  * fix: Respect GLAMOUR_STYLE env on issue view (#317)
  * refactor!: Move boards and project list to subcommand (#314)
  * dep: Upgrade outdated packages (#311)
  * dep: Upgrade rivo/tview to latest (#310)
  * dep: Upgrade charmbracelet/glamour to 0.5.0 (#309)
  * feat: Add --no-browser option to open cmd (#308)
  * feat: Allow insecure TLS (#305)
  * fix: Jira client should respect timeout opt (#304)
  * chore: Change the logo color to be white for consitency (#299)
  * doc: Add backers badge
  * dev: Upgrade jira
  * fix(cfg): Strip trailing slash on server name (#295)
  * feat: Allow to set fixVersions on issue creation (#276)
  * fix: Config generation issue (#275)
  * doc: Add the FreeBSD and NetBSD badge. (#270)
  * dev: Fix Makefile compatiblity with Make 3.81 (#252)
